%bcond_with windows
%bcond_with tests

Summary:       Convert a virtual machine to run on KVM
Name:          virt-v2v
Version:       2.2.0
Release:       2%{?dist}
License:       GPLv2+
URL:           https://github.com/libguestfs/virt-v2v
Source0:       https://download.libguestfs.org/virt-v2v/2.2-stable/%{name}-%{version}.tar.gz

ExclusiveArch: x86_64
BuildRequires: gcc make autoconf automake libtool glibc-static
BuildRequires: augeas-devel file-devel gettext-devel jansson-devel
BuildRequires: libguestfs-devel libnbd-devel libvirt-daemon-kvm libvirt-devel
BuildRequires: libosinfo-devel libxml2-devel pcre2-devel
BuildRequires: po4a perl(Sys::Guestfs) xorriso bash-completion
BuildRequires: /usr/bin/pod2man /usr/bin/virsh
BuildRequires: ocaml
BuildRequires: ocaml-findlib-devel ocaml-fileutils-devel ocaml-gettext-devel
BuildRequires: ocaml-libguestfs-devel ocaml-libvirt-devel ocaml-libnbd-devel
%if %{with tests}
BuildRequires: %{_bindir}/qemu-nbd %{_bindir}/nbdcopy %{_bindir}/nbdinfo
BuildRequires: nbdkit-file-plugin nbdkit-null-plugin nbdkit-python-plugin nbdkit-cow-filter
%endif

Requires:      gawk gzip unzip curl python3
Requires:      openssh-clients >= 8.8p1
Requires:      edk2-ovmf
Requires:      libnbd libguestfs guestfs-tools
Requires:      %{_bindir}/virsh %{_bindir}/qemu-nbd %{_bindir}/nbdcopy %{_bindir}/nbdinfo
Requires:      nbdkit-server nbdkit-curl-plugin nbdkit-file-plugin nbdkit-nbd-plugin
Requires:      nbdkit-null-plugin nbdkit-python-plugin nbdkit-ssh-plugin nbdkit-vddk-plugin
Requires:      nbdkit-blocksize-filter nbdkit-cacheextents-filter nbdkit-cow-filter
Requires:      nbdkit-multi-conn-filter nbdkit-rate-filter nbdkit-retry-filter
%if %{with windows}
Requires:      libguestfs-winsupport >= 7.2
Requires:      mingw32-srvany >= 1.0-13
Recommends:    virtio-win
%endif

%description
Virt-v2v is a program that converts a single guest from a foreign
hypervisor to run on KVM.  It can read Linux and Windows guests
running on VMware, Xen, Hyper-V and some other hypervisors, and
convert them to KVM managed by libvirt, OpenStack, oVirt, Red Hat
Virtualisation (RHV) or several other targets.  It can modify the
guest to make it bootable on KVM and install virtio drivers so it will
run quickly.


%package bash-completion
Summary:       Bash tab-completion for %{name}
BuildArch:     noarch
Requires:      bash-completion
Requires:      %{name} = %{version}-%{release}

%description bash-completion
Bash tab-completion for %{name}.


%prep
%autosetup -p1


%build
autoreconf -i
%configure
%{make_build}


%install
%make_install
find $RPM_BUILD_ROOT -name '*.la' -delete
rm $RPM_BUILD_ROOT%{_bindir}/virt-v2v-in-place
rm $RPM_BUILD_ROOT%{_mandir}/man1/virt-v2v-in-place.1*

%if %{with windows}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/virt-tools
pushd $RPM_BUILD_ROOT%{_datadir}/virt-tools
ln -sf ../../i686-w64-mingw32/sys-root/mingw/bin/rhsrvany.exe
ln -sf ../../i686-w64-mingw32/sys-root/mingw/bin/pnp_wait.exe
popd
%endif

%find_lang %{name}


%check
%if %{with tests}
if grep CONFIG_DEBUG_MUTEXES=y /lib/modules/*/config ; then
    echo "Skipping tests because debug kernel is installed"
    exit 0
fi

export LIBGUESTFS_DEBUG=1
export LIBGUESTFS_TRACE=1

for f in *.img; do
    make -C test-data/phony-guests $f
    if -s test-data/phony-guests/$f; then
        ./run virt-v2v -v -x -i disk test-data/phony-guests/$f -o null
    fi
done
%endif


%files -f %{name}.lang
%license COPYING
%doc README
%{_bindir}/virt-v2v
%{_bindir}/virt-v2v-inspector
%{_mandir}/man1/virt-v2v.1*
%{_mandir}/man1/virt-v2v-hacking.1*
%{_mandir}/man1/virt-v2v-input-vmware.1*
%{_mandir}/man1/virt-v2v-input-xen.1*
%{_mandir}/man1/virt-v2v-inspector.1*
%{_mandir}/man1/virt-v2v-output-local.1*
%{_mandir}/man1/virt-v2v-output-openstack.1*
%{_mandir}/man1/virt-v2v-output-rhv.1*
%{_mandir}/man1/virt-v2v-release-notes-1.42.1*
%{_mandir}/man1/virt-v2v-release-notes-2.0.1*
%{_mandir}/man1/virt-v2v-release-notes-2.2.1*
%{_mandir}/man1/virt-v2v-support.1*
%exclude %{_mandir}/ja/man1/*.1*
%exclude %{_mandir}/uk/man1/*.1*
%if %{with windows}
%{_datadir}/virt-tools
%endif


%files bash-completion
%license COPYING
%{_datadir}/bash-completion/completions/virt-v2v


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.2.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Mar 30 2023 rockerzhu <rockerzhu@tencent.com> - 2.2.0-1
- Initial build
